@@ -449,6 +449,12 @@ class Model(object):
                             " find the 'model' key in the resource:\n\n%s" %
                             model)
 
+    def resource(self):
+        """Returns the model resource ID
+
+        """
+        return self.resource_id
+
     def fields(self, out=sys.stdout):
         """Describes and return the fields for this model.
 
@@ -461,6 +467,42 @@ class Model(object):
         """
         return self.tree.get_leaves()
 
+    def filter_input_data(self, input_data, by_name=True):
+        """Filters the keys given in input_data checking against model fields
+
+        """
+
+        if isinstance(input_data, dict):
+            empty_fields = [(key, value) for (key, value) in input_data.items()
+                            if value is None]
+            for (key, value) in empty_fields:
+                del input_data[key]
+
+
+            if by_name:
+                # Checks input_data keys against field names and filters the
+                # ones used in the model
+                wrong_keys = [key for key in input_data.keys() if not key
+                              in self.all_inverted_fields]
+                if wrong_keys:
+                    LOGGER.error("Wrong field names in input data: %s" %
+                                 ", ".join(wrong_keys))
+                input_data = dict(
+                    [[self.inverted_fields[key], value]
+                        for key, value in input_data.items()
+                        if key in self.inverted_fields])
+            else:
+                input_data = dict(
+                    [[key, value]
+                        for key, value in input_data.items()
+                        if key in self.tree.fields])
+            return input_data
+        else:
+            LOGGER.error("Failed to read input data in the expected"
+                         " {field:value} format.")
+            return {}
+
+
     def predict(self, input_data, by_name=True,
                 print_path=False, out=sys.stdout, with_confidence=False):
         """Makes a prediction based on a number of field values.
@@ -469,29 +511,8 @@ class Model(object):
         `by_name` to input them directly keyed by id.
 
         """
-        # Strips None values
-        empty_fields = [(key, value) for (key, value) in input_data.items()
-                        if value is None]
-        for (key, value) in empty_fields:
-            del input_data[key]
-
-        # Checks input_data keys against field names and filters the ones
-        # used in the model
-        if by_name:
-            wrong_keys = [key for key in input_data.keys() if not key
-                          in self.all_inverted_fields]
-            if wrong_keys:
-                LOGGER.error("Wrong field names in input data: %s" %
-                             ", ".join(wrong_keys))
-            input_data = dict(
-                [[self.inverted_fields[key], value]
-                    for key, value in input_data.items()
-                    if key in self.inverted_fields])
-        else:
-            input_data = dict(
-                [[key, value]
-                    for key, value in input_data.items()
-                    if key in self.tree.fields])
+        # Checks and cleans input_data leaving the fields used in the model
+        input_data = self.filter_input_data(input_data, by_name=by_name)
 
         # Strips affixes for numeric values and casts to the final field type
         cast(input_data, self.tree.fields)
